function newGps = gpstimelag(origGps,secOffset)
%GPSTIMELAG Offset GPS value by time lag and check that lagged events are still within epoch
%
%SYNOPSIS
%   NEWGPS = gpstimelag(ORIGGPS, SECOFFSET)
%
%INPUT
%   ORIGGPS     original GPS structure (sec,ns)
%   SECOFFSET   offset time in digital seconds
%   *** We assume the offset time is how much the raw time series
%           is shifted.  For reconstructed events, we need to
%           shift in the OPPOSITE direction.
%
%OUTPUT
%   NEWGPS      new GPS structure offset by subtracting time lag entry has
%       seconds = 0 if outside the epoch !
%
%   *** Uses Epochs to check that lagged event is still within epoch
%       -- requires epochlimits
%
%AUTHOR
%   Keith Thorne <keith.thorne@ligo.org>

% $Id: gpstimelag.m 6645 2010-12-09 16:09:14Z diego.menendez@LIGO.ORG $

% IF offset = 0 THEN
%   SET new GPS time to existing values
%   EXIT
% ENDIF
% SET new GPS time = original GPS time - input time offset
% LOOP over GPS times
%   GET limits of epoch for original GPS time
%   IF limits are found
%       IF new (lagged) GPS time is outside epoch limits
%           SET new GPS time to null value
%       ENDIF
%   ELSE
%       SET new GPS time to null value
%   ENDIF
% ENDLOOP
newGps = [];
if(~isstruct(secOffset))
    if(secOffset == 0)
        newGps = origGps;
        return
    end
else
    offTime = gps2time(secOffset);
    if(offTime == 0)
        newGps = origGps;
        return
    end
end
newGps = gpsdiff(origGps,secOffset);
[mrows,ncols]=size(origGps);
for ir = 1:mrows
    for ic = 1:ncols
        [epochStart,epochDur]=epochlimits('get',origGps(ir,ic).sec);
        if(~isempty(epochStart))
            newTime = gps2time(newGps(ir,ic));
            if((newTime > (epochStart+epochDur)) || (newTime < epochStart))
                newGps(ir,ic).sec = 0;
                newGps(ir,ic).ns = 0;
            end
       else
            newGps(ir,ic).sec = 0;
            newGps(ir,ic).ns = 0;
       end
    end
end
return

